@@ -4,6 +4,7 @@
    Copyright 1997-2005 Douglas M. Bates <bates@stat.wisc.edu>,
 		       Jose C. Pinheiro,
 		       Saikat DebRoy
+   Copyright 2007-2012  The R Core Team
 
    This file is part of the nlme package for R and related languages
    and is made available under the terms of the GNU General Public
@@ -57,7 +58,7 @@ gnls_init(double *ptheta, longint *dims, double *corFactor, double *varWeights,
   gnls->N = dims[1];
   gnls->nrdof = gnls->N - gnls->npar;
   gnls->ncol = gnls->npar + 1;
-  gnls->maxIter = (long) settings[0];
+  gnls->maxIter = (int) settings[0];
   gnls->minFactor = settings[1];
   gnls->tolerance = settings[2];
   gnls->newtheta = Calloc(gnls->npar, double);
